from archicad import ACConnection

conn = ACConnection.connect()
assert conn

acc = conn.commands
act = conn.types
acu = conn.utilities

################################ CONFIGURATION #################################
propertyId = acu.GetUserDefinedPropertyId("ZONES", "Zone Overall")
elements = acc.GetElementsByType('Zone')

def GeneratePropertyValueString(width: float, height: float) -> str:
    # show highest value first - office preference.
    if width > height:
        return f"{width:.2f} x {height:.2f}"
    else:
        return f"{height:.2f} x {width:.2f}"
################################################################################


def generatePropertyValue(width: float, height: float) -> act.NormalStringPropertyValue:
    return act.NormalStringPropertyValue(GeneratePropertyValueString(width, height))


# collect all the data
boundingBoxes = acc.Get2DBoundingBoxes(elements)

# bind bounding boxes to element ids
elementBoundingBoxDict = dict(zip(elements, boundingBoxes))

# calculated the widths and heights
elemPropertyValues = []
for key,value in elementBoundingBoxDict.items():
        width = abs(value.boundingBox2D.xMax - value.boundingBox2D.xMin)
        height = abs(value.boundingBox2D.yMax - value.boundingBox2D.yMin)
        
        newPropertyValue = generatePropertyValue(width, height)
        elemPropertyValues.append(act.ElementPropertyValue(key.elementId, propertyId, newPropertyValue))
 
# set the new property values
acc.SetPropertyValuesOfElements(elemPropertyValues)
